# Remaining issues:
#
# Upstream Issues
#
# - enable simpleSAMLphp modules through (main) config file
#   ISSUE: http://code.google.com/p/simplesamlphp/issues/detail?id=475
#
# - more configurable paths in config.php
#   ISSUE: http://code.google.com/p/simplesamlphp/issues/detail?id=349
#
# Packaging Issues
#
# - Place certificate(s) in /etc/pki/simplesamlphp. See
#   http://fedoraproject.org/wiki/PackagingDrafts/Certificates
#
# - Figure out the status of the bundled 'xmlseclibs.php' (separate package?) 
#   There is also a SAML2 directory, which seems to not "belong" to 
#   simpleSAMLphp?
#
# - Deal with bundled JavaScript (jquery, jquery-ui, ...) and also image sets?
# 
# - Make the log to file in /var/log/simplesamlphp actually work (permissions + 
#   SELinux)
#
# - Allow Apache to write to /var/lib/simplesamlphp/metadata (permissions + 
#   SELinux) for the "metarefresh" plugin
#
# - Figure out where "attributemap" belongs, Debian puts it in 
#   /etc/simplesamlphp, we should probably do that too
# 
# - Include a README.dist or similar file explaining the configuration specific
#   items for Fedora (and SELinux)
#
# - Maybe prepare a cron example file (for metarefresh)
#
# - Figure out all licenses used in simpleSAMLphp. Debian package list some
#

Name:		simplesamlphp
Version:	1.8.2
Release:	2%{?dist}
Summary:	PHP SAML 2.0 service provider and identity provider

Group:		Applications/Internet
License:	LGPLv2
URL:		http://simplesamlphp.org/
Source0:	http://simplesamlphp.googlecode.com/files/simplesamlphp-%{version}.tar.gz
Source1:	simplesamlphp-httpd-conf

# ISSUE: http://code.google.com/p/simplesamlphp/issues/detail?id=476
# COMMIT: http://code.google.com/p/simplesamlphp/source/detail?r=3030
Patch0:         simplesamlphp_secretsalt_warning.patch

BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

Requires:	webserver
Requires:	php >= 5.2.0
Requires:	php-ldap
Requires:	php-xml
Requires:	php-pdo
Requires:	php-mcrypt
Requires:	php-mysql
Requires:	php-pecl-radius

# php-pear-Auth-OpenID is not packaged in EPEL :(
Requires:	php-pear-Auth-OpenID

BuildArch:	noarch
 
%description
SimpleSAMLphp is an award-winning application written in native PHP 
that deals with authentication. The project is led by UNINETT, has a 
large user base, a helpful user community and a large set of 
external contributors.

SimpleSAMLphp is having a main focus on providing support for:

    SAML 2.0 as a Service Provider.
    SAML 2.0 as a Identity Provider.

But also supports some other identity protocols, such as Shibboleth 
1.3, A-Select, CAS, OpenID, WS-Federation and OAuth.

%prep
%setup -q

%patch0 -p1

# fix execute permission on some files (shamelessly taken from Debian package)
find . -type f -executable -not -path '*/bin/*' | xargs chmod -x

%build

%install
rm -rf ${RPM_BUILD_ROOT}

mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/cert
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/metadata
mkdir -p ${RPM_BUILD_ROOT}%{_datadir}/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}/data
mkdir -p ${RPM_BUILD_ROOT}%{_localstatedir}/lib/%{name}/metadata

install -m 0644 -D -p %{SOURCE1} ${RPM_BUILD_ROOT}%{_sysconfdir}/httpd/conf.d/%{name}.conf

cp -pr config-templates/* ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}
cp -pr metadata-templates/* ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/metadata
cp -pr cert/* ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/cert

# fix config
sed -i "s|'baseurlpath'           => 'simplesaml/'|'baseurlpath'           => 'simplesamlphp/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php
sed -i "s|'datadir'               => 'data/'|'datadir'               => '/var/lib/simplesamlphp/data/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php
sed -i "s|'loggingdir'            => 'log/'|'loggingdir'            => '/var/log/simplesamlphp/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php
sed -i "s|'certdir'               => 'cert/'|'certdir'               => '/etc/simplesamlphp/cert/'|g" ${RPM_BUILD_ROOT}%{_sysconfdir}/%{name}/config.php

cp -pr * ${RPM_BUILD_ROOT}%{_datadir}/%{name}

rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/config 
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/metadata 
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/data 
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/cert
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/log 
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/docs
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/COPYING
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/%{name}/lib/Auth

ln -sf ../../../etc/simplesamlphp ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/config
ln -sf ../../../etc/simplesamlphp/metadata ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/metadata
ln -sf ../../../../usr/share/pear/Auth_OpenID ${RPM_BUILD_ROOT}%{_datadir}/simplesamlphp/lib/Auth

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}
%{_datadir}/%{name}
%{_localstatedir}/lib/%{name}
%doc docs/ COPYING

%changelog
* Tue Feb 14 2012 F. Kooman <fkooman@tuxed.net> - 1.8.2-2
- remove included PHP OpenID library, use system version instead
- update Apache config to only allow localhost by default
- apply patch to warn if secretsalt is still set to the default

* Wed Feb 11 2012 F. Kooman <fkooman@tuxed.net> - 1.8.2-1
- initial package based on previous work by Gijs Molenaar, Xander Jansen,
  Victoriano Giralt (RPM package) and Thijs Kinkhorst (Debian package).

